#include <SPI.h>
#include <MFRC522.h>

/*
 * Initial Author: ryand1011 (https://github.com/ryand1011)
 *
 * Reads data written by a program such as "rfid_write_personal_data.ino"
 *
 * See: https://github.com/miguelbalboa/rfid/tree/master/examples/rfid_write_personal_data
 *
 * Uses MIFARE RFID card using RFID-RC522 reader
 * Uses MFRC522 - Library
 * -----------------------------------------------------------------------------------------
 *             MFRC522      Arduino       Arduino   Arduino    Arduino          Arduino
 *             Reader/PCD   Uno/101       Mega      Nano v3    Leonardo/Micro   Pro Micro
 * Signal      Pin          Pin           Pin       Pin        Pin              Pin
 * -----------------------------------------------------------------------------------------
 * RST/Reset   RST          9             5         D9         RESET/ICSP-5     RST
 * SPI SS      SDA(SS)      10            53        D10        10               10
 * SPI MOSI    MOSI         11 / ICSP-4   51        D11        ICSP-4           16
 * SPI MISO    MISO         12 / ICSP-1   50        D12        ICSP-1           14
 * SPI SCK     SCK          13 / ICSP-3   52        D13        ICSP-3           15
 *
 * More pin layouts for other boards can be found here: https://github.com/miguelbalboa/rfid#pin-layout
*/

#define SS_PIN 10
#define RST_PIN 9
#define DIODA_CZER 7
#define DIODA_ZIEL 8

MFRC522 mfrc522(SS_PIN, RST_PIN);

String calosc = "";

void setup() {
  Serial.begin(9600);
  SPI.begin();
  mfrc522.PCD_Init();
  Serial.println("Czytnik wystartowal");
}
void loop() {
  if (mfrc522.PICC_IsNewCardPresent())
  {
    if (mfrc522.PICC_ReadCardSerial())
    {
      for (byte i = 0; i < mfrc522.uid.size; i++)
      {
        calosc += String(mfrc522.uid.uidByte[i], HEX); 
      }
      Serial.print("UID wykrytej karty: ");
      Serial.println(calosc);
      mfrc522.PICC_HaltA();
    }

    if (calosc == "99a7ecc2")
    {
      analogWrite(DIODA_ZIEL, 255);
      delay(1000);
      digitalWrite(DIODA_ZIEL, 0);
      calosc = "";
    }
    else
    {
      analogWrite(DIODA_CZER, 255);
      delay(1000);
      analogWrite(DIODA_CZER, 0);
      calosc = "";
    }
  }
}
